# Blocks

### Blockquote

Blockquotes are used to indicate quoted or referenced text, often used for citations, excerpts, or highlighting important information. They are created by prefixing the text with a greater-than symbol (>), followed by a space.

    > blockquote

#### Examples

> blockquote

### Code

Code Blocks () or (~~~): Code blocks are used to display lines or blocks of code without any formatting or interpretation. This block is not effected by `\n`.

    `code`

#### Examples

`code`

### Code (Full width)

    ```
    code
    ```

#### Examples

    code